@@ -1588,7 +1588,7 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
         dpkg_architecture_variables = context.dpkg_architecture_variables
 
         meson_flags = [
-            "--wrap-mode=odownload",
+            "--wrap-mode=nodownload",
             "--buildtype=plain",
             "--sysconfdir=/etc",
             "--localstatedir=/var",
@@ -1596,7 +1596,7 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
             "--auto-features=enabled",
         ]
         if meson_version >= Version("1.2.0"):
-            # There was a behaviour change in Meson 1.2.0: previously
+            # There was a behavior change in Meson 1.2.0: previously
             # byte-compilation wasn't supported, but since 1.2.0 it is on by
             # default. We can only use this option to turn it off in versions
             # where the option exists.
@@ -1642,7 +1642,7 @@ class MesonBuildSystemRule(StepBasedBuildSystemRule):
         **kwargs,
     ) -> None:
         env_mod = EnvironmentModification(
-            replacements=(("MESON_TESTTHREDS", f"{context.parallelization_limit()}"),),
+            replacements=(("MESON_TESTTHREADS", f"{context.parallelization_limit()}"),),
         ).combine(self._default_meson_env())
         with self.dump_logs_on_error("meson-logs/testlog.txt"):
             run_build_system_command(
@@ -1868,7 +1868,6 @@ class Qmake6BuildSystemRule(AbstractQmakeBuildSystemRule):
     online_reference_documentation=reference_documentation(
         title="Make Build System",
         description=textwrap.dedent(
-            ""
             """\
         Run a plain `make` file with nothing else.
 
